@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -25,7 +25,7 @@ class NoteEditorUtilsTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit NoteEditorUtilsTest(QObject *parent = Q_NULLPTR);
+    explicit NoteEditorUtilsTest(QObject *parent = nullptr);
     ~NoteEditorUtilsTest();
 
 private Q_SLOTS:
