@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,11 +19,12 @@
 #ifndef NOTEEDITOR_H
 #define NOTEEDITOR_H
 
-#include <kpimtextedit/richtexteditorwidget.h>
+#include <KPIMTextEdit/RichTextEditorWidget>
 
 namespace NoteShared {
 class NoteEditor : public KPIMTextEdit::RichTextEditorWidget
 {
+    Q_OBJECT
 public:
     explicit NoteEditor(QWidget *parent);
     ~NoteEditor();
