@@ -33,23 +33,20 @@
 #include "notehostdialog.h"
 #include "notesharedglobalconfig.h"
 
-#include <kconfig.h>
-#include "noteshared_debug.h"
-#include <khistorycombobox.h>
+#include <KHistoryComboBox>
 #include <KLocalizedString>
+#include <KDNSSD/DNSSD/ServiceBrowser>
+#include <KDNSSD/DNSSD/ServiceModel>
 
-#include <QVBoxLayout>
-#include <dnssd/servicemodel.h>
-#include <dnssd/servicebrowser.h>
-
-#include <QLineEdit>
-#include <QLabel>
-#include <QString>
-#include <QTreeView>
 #include <QDialogButtonBox>
+#include <QLabel>
+#include <QLineEdit>
 #include <QPushButton>
+#include <QTreeView>
+#include <QVBoxLayout>
 
 using namespace NoteShared;
+
 NoteHostDialog::NoteHostDialog(const QString &caption, QWidget *parent)
     : QDialog(parent)
 {
@@ -69,12 +66,14 @@ NoteHostDialog::NoteHostDialog(const QString &caption, QWidget *parent)
 
     m_servicesView = new QTreeView(this);
     m_servicesView->setRootIsDecorated(false);
-    KDNSSD::ServiceModel *mdl = new KDNSSD::ServiceModel(new KDNSSD::ServiceBrowser(QStringLiteral("_knotes._tcp"), true), this);
+    KDNSSD::ServiceModel *mdl
+        = new KDNSSD::ServiceModel(new KDNSSD::ServiceBrowser(QStringLiteral("_knotes._tcp"), true), this);
     m_servicesView->setModel(mdl);
     m_servicesView->setSelectionBehavior(QAbstractItemView::SelectRows);
     m_servicesView->hideColumn(KDNSSD::ServiceModel::Port);
-    connect(m_servicesView->selectionModel(), &QItemSelectionModel::currentRowChanged, this, &NoteHostDialog::serviceSelected);
 
+    connect(m_servicesView->selectionModel(), &QItemSelectionModel::currentRowChanged,
+            this, &NoteHostDialog::serviceSelected);
     connect(m_servicesView, &QTreeView::activated, this, &NoteHostDialog::serviceSelected);
     connect(m_servicesView, &QTreeView::clicked, this, &NoteHostDialog::serviceSelected);
     connect(m_servicesView, &QTreeView::doubleClicked, this, &NoteHostDialog::slotServiceDoubleClicked);
@@ -145,6 +144,6 @@ quint16 NoteHostDialog::port() const
 void NoteHostDialog::slotServiceDoubleClicked(const QModelIndex &idx)
 {
     KDNSSD::RemoteService::Ptr srv = idx.data(KDNSSD::ServiceModel::ServicePtrRole).value<KDNSSD::RemoteService::Ptr>();
-    m_hostCombo->lineEdit()->setText(srv->hostName() + QLatin1String(":") + QString::number(srv->port()));
+    m_hostCombo->lineEdit()->setText(srv->hostName() + QLatin1Char(':') + QString::number(srv->port()));
     accept();
 }
