@@ -40,7 +40,6 @@
 #include <QTimer>
 #include <QTextCodec>
 #include "noteshared_debug.h"
-#include <KLocalizedString>
 #include <QLocale>
 
 // Maximum note size in chars we are going to accept,
@@ -71,10 +70,10 @@ public:
         delete m_sock;
     }
 
-    QTimer *m_timer;       // to avoid memory and connection floods
+    QTimer *m_timer = nullptr;       // to avoid memory and connection floods
 
-    QByteArray *m_buffer;
-    QTcpSocket *m_sock;
+    QByteArray *m_buffer = nullptr;
+    QTcpSocket *m_sock = nullptr;
 
     QString m_titleAddon;
 };
@@ -93,7 +92,7 @@ NotesNetworkReceiver::NotesNetworkReceiver(QTcpSocket *s)
     // Setup the communications
     connect(d->m_sock, &QTcpSocket::readyRead, this, &NotesNetworkReceiver::slotDataAvailable);
     connect(d->m_sock, &QTcpSocket::disconnected, this, &NotesNetworkReceiver::slotConnectionClosed);
-    connect(d->m_sock, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)>(&QTcpSocket::error), this, &NotesNetworkReceiver::slotError);
+    connect(d->m_sock, QOverload<QAbstractSocket::SocketError>::of(&QTcpSocket::error), this, &NotesNetworkReceiver::slotError);
 
     // Setup the timer
     d->m_timer = new QTimer(this);
