@@ -35,7 +35,6 @@ using namespace NoteShared;
 
 NoteUtils::NoteUtils()
 {
-
 }
 
 bool NoteUtils::sendToMail(QWidget *parent, const QString &title, const QString &message)
@@ -69,7 +68,6 @@ void NoteUtils::sendToNetwork(QWidget *parent, const QString &title, const QStri
     // pop up dialog to get the IP
     QPointer<NoteShared::NoteHostDialog> hostDlg = new NoteShared::NoteHostDialog(i18n("Send \"%1\"", title), parent);
     if (hostDlg->exec()) {
-
         const QString host = hostDlg->host();
         if (host.isEmpty()) {
             KMessageBox::sorry(parent, i18n("The host cannot be empty."));
@@ -109,42 +107,41 @@ QString NoteUtils::createToolTip(const Akonadi::Item &item)
         NoteDisplayAttribute *attr = item.attribute<NoteDisplayAttribute>();
         if (attr) {
             const QString bckColorName = attr->backgroundColor().name();
-            const QString txtColorName = attr->foregroundColor().name();;
+            const QString txtColorName = attr->foregroundColor().name();
             const bool textIsLeftToRight = (QApplication::layoutDirection() == Qt::LeftToRight);
-            const QString textDirection =  textIsLeftToRight ? QStringLiteral("left") : QStringLiteral("right");
+            const QString textDirection = textIsLeftToRight ? QStringLiteral("left") : QStringLiteral("right");
 
             tip = QStringLiteral(
-                      "<table width=\"100%\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">"
-                  );
+                "<table width=\"100%\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">"
+                );
             tip += QStringLiteral(
-                       "<tr>" \
-                       "<td bgcolor=\"%1\" align=\"%4\" valign=\"middle\">" \
-                       "<div style=\"color: %2; font-weight: bold;\">" \
-                       "%3" \
-                       "</div>" \
-                       "</td>" \
-                       "</tr>"
-                   ).arg(bckColorName, txtColorName ,realName.toHtmlEscaped() ,textDirection);
+                "<tr>" \
+                "<td bgcolor=\"%1\" align=\"%4\" valign=\"middle\">" \
+                "<div style=\"color: %2; font-weight: bold;\">" \
+                "%3" \
+                "</div>" \
+                "</td>" \
+                "</tr>"
+                ).arg(bckColorName, txtColorName, realName.toHtmlEscaped(), textDirection);
             const QString htmlCodeForStandardRow = QStringLiteral(
-                    "<tr>" \
-                    "<td bgcolor=\"%1\" align=\"left\" valign=\"top\">" \
-                    "<div style=\"color: %2;\">" \
-                    "%3" \
-                    "</div>" \
-                    "</td>" \
-                    "</tr>");
+                "<tr>" \
+                "<td bgcolor=\"%1\" align=\"left\" valign=\"top\">" \
+                "<div style=\"color: %2;\">" \
+                "%3" \
+                "</div>" \
+                "</td>" \
+                "</tr>");
 
             QString content = description;
             if (!content.trimmed().isEmpty()) {
                 tip += htmlCodeForStandardRow.arg(bckColorName, txtColorName, isRichText ? content : content.replace(QLatin1Char('\n'), QStringLiteral("<br>")));
             }
             tip += QLatin1String(
-                       "</table" \
-                       "</td>" \
-                       "</tr>"
-                   );
+                "</table" \
+                "</td>" \
+                "</tr>"
+                );
         }
     }
     return tip;
 }
-
