@@ -18,74 +18,58 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
 
-#include "config-knotes.h"
-#include "configdialog/knoteconfigdialog.h"
+#include <config-knotes.h>
 
-#include "dialog/knoteselectednotesdialog.h"
-#include "utils/knoteutils.h"
-#include "akonadi/notesakonaditreemodel.h"
-#include "akonadi/noteschangerecorder.h"
-#include "attributes/notelockattribute.h"
-#include "attributes/notelockattribute.h"
-#include "attributes/notealarmattribute.h"
-#include "attributes/showfoldernotesattribute.h"
-
-#include "job/createnewnotejob.h"
-
-#include "apps/knotesakonaditray.h"
-
-#include "notesharedglobalconfig.h"
-#include "notes/knote.h"
-#include "knotesadaptor.h"
 #include "knotesapp.h"
-#include "print/knoteprinter.h"
-#include "print/knoteprintobject.h"
+#include "knotes_debug.h"
+#include "knotesadaptor.h"
 #include "knotesglobalconfig.h"
-#include "dialog/knoteskeydialog.h"
+#include "notesharedglobalconfig.h"
+#include "akonadi/noteschangerecorder.h"
+#include "akonadi/notesakonaditreemodel.h"
+#include "apps/knotesakonaditray.h"
+#include "attributes/notealarmattribute.h"
+#include "attributes/notedisplayattribute.h"
+#include "attributes/notelockattribute.h"
+#include "attributes/showfoldernotesattribute.h"
+#include "configdialog/knoteconfigdialog.h"
 #include "dialog/knotedeleteselectednotesdialog.h"
-#include "print/knoteprintselectednotesdialog.h"
+#include "dialog/knoteskeydialog.h"
 #include "finddialog/knotefinddialog.h"
+#include "job/createnewnotejob.h"
+#include "notes/knote.h"
+#include "print/knoteprinter.h"
+#include "print/knoteprintselectednotesdialog.h"
+#include "resources/localresourcecreator.h"
+#include "utils/knoteutils.h"
 
-#include <KMime/KMimeMessage>
-#include <AkonadiCore/ItemCreateJob>
+#include <AkonadiCore/ChangeRecorder>
 #include <AkonadiCore/ItemDeleteJob>
-#include <AkonadiCore/EntityDisplayAttribute>
 #include <AkonadiCore/ItemFetchJob>
 #include <AkonadiCore/ItemFetchScope>
-
-#include <AkonadiWidgets/controlgui.h>
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiCore/Collection>
-#include <AkonadiCore/EntityTreeModel>
 #include <AkonadiCore/Session>
-#include <Akonadi/Notes/NoteUtils>
+
+#include <AkonadiWidgets/ControlGui>
+
+#include <KMime/KMimeMessage>
+
 #include <KActionCollection>
-#include <resources/localresourcecreator.h>
-#include <attributes/notedisplayattribute.h>
-
-#include <KMessageBox>
-#include "knotes_debug.h"
-#include <khelpmenu.h>
-#include <kiconeffect.h>
-#include <KLocalizedString>
-#include <QMenu>
-#include <kshortcutsdialog.h>
-#include <kstandardaction.h>
-#include <ksystemtrayicon.h>
-#include <kwindowsystem.h>
-#include <kxmlguibuilder.h>
-#include <kxmlguifactory.h>
-#include <QFileDialog>
-#include <QApplication>
-
-#include <kiconloader.h>
 #include <KGlobalAccel>
+#include <KIconEffect>
+#include <KIconLoader>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KWindowSystem>
+#include <KXMLGUIBuilder>
+#include <KXMLGUIFactory>
+#include <KDNSSD/DNSSD/PublicService>
 
-#include <QPixmap>
+#include <QAction>
+#include <QApplication>
 #include <QClipboard>
 #include <QDBusConnection>
-
-#include <dnssd/publicservice.h>
+#include <QFileDialog>
+#include <QMenu>
 
 static bool qActionLessThan(const QAction *a1, const QAction *a2)
 {
@@ -95,11 +79,11 @@ static bool qActionLessThan(const QAction *a1, const QAction *a2)
 KNotesApp::KNotesApp()
     : QWidget()
     , m_publisher(nullptr)
-    , mDebugBaloo(false)
+    , mDebugAkonadiSearch(false)
 {
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
 
-    mDebugBaloo = !qEnvironmentVariableIsEmpty("KDEPIM_BALOO_DEBUG");
+    mDebugAkonadiSearch = !qEnvironmentVariableIsEmpty("KDEPIM_DEBUGGING");
 
     if (KNotesGlobalConfig::self()->autoCreateResourceOnStart()) {
         NoteShared::LocalResourceCreator *creator = new NoteShared::LocalResourceCreator(this);
@@ -114,7 +98,9 @@ KNotesApp::KNotesApp()
                                   i18n("New Note"), this);
     actionCollection()->addAction(QStringLiteral("new_note"), action);
     KGlobalAccel::setGlobalShortcut(action, QKeySequence(Qt::ALT + Qt::SHIFT + Qt::Key_N));
-    connect(action, SIGNAL(triggered()), SLOT(newNote()));
+    connect(action, &QAction::triggered, this, [this]() {
+        newNote();
+    });
 
     action = new QAction(QIcon::fromTheme(QStringLiteral("edit-paste")),
                          i18n("New Note From Clipboard"), this);
@@ -197,8 +183,12 @@ KNotesApp::KNotesApp()
     mNoteRecorder = new NoteShared::NotesChangeRecorder(this);
     mNoteRecorder->changeRecorder()->setSession(session);
     mTray = new KNotesAkonadiTray(nullptr);
-    connect(mTray, &KStatusNotifierItem::activateRequested, this, &KNotesApp::slotActivateRequested);
-    connect(mTray, &KStatusNotifierItem::secondaryActivateRequested, this, &KNotesApp::slotSecondaryActivateRequested);
+
+    connect(mTray, &KStatusNotifierItem::activateRequested,
+            this, &KNotesApp::slotActivateRequested);
+
+    connect(mTray, &KStatusNotifierItem::secondaryActivateRequested,
+            this, &KNotesApp::slotSecondaryActivateRequested);
 
     mTray->setContextMenu(contextMenu);
     mNoteTreeModel = new NoteShared::NotesAkonadiTreeModel(mNoteRecorder->changeRecorder(), this);
@@ -206,10 +196,18 @@ KNotesApp::KNotesApp()
     connect(mNoteTreeModel, &QAbstractItemModel::rowsInserted,
             this, &KNotesApp::slotRowInserted);
 
-    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemChanged, this, &KNotesApp::slotItemChanged);
-    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved, this, &KNotesApp::slotItemRemoved);
-    connect(mNoteRecorder->changeRecorder(), SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)), SLOT(slotCollectionChanged(Akonadi::Collection,QSet<QByteArray>)));
-    connect(qApp, &QGuiApplication::commitDataRequest, this, &KNotesApp::slotCommitData, Qt::DirectConnection);
+    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemChanged,
+            this, &KNotesApp::slotItemChanged);
+
+    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved,
+            this, &KNotesApp::slotItemRemoved);
+
+    connect(mNoteRecorder->changeRecorder(), SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)),
+            SLOT(slotCollectionChanged(Akonadi::Collection,QSet<QByteArray>)));
+
+    connect(qApp, &QGuiApplication::commitDataRequest,
+            this, &KNotesApp::slotCommitData, Qt::DirectConnection);
+
     QGuiApplication::setFallbackSessionManagementEnabled(false);
     updateNoteActions();
 }
@@ -278,7 +276,8 @@ void KNotesApp::slotRowInserted(const QModelIndex &parent, int start, int end)
             const QModelIndex child = mNoteTreeModel->index(i, 0, parent);
             Akonadi::Item item
                 = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
-            Akonadi::Collection parentCollection = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
+            Akonadi::Collection parentCollection
+                = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
             if (parentCollection.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
                 createNote(item);
                 needUpdate = true;
@@ -294,8 +293,7 @@ void KNotesApp::slotRowInserted(const QModelIndex &parent, int start, int end)
 void KNotesApp::createNote(const Akonadi::Item &item)
 {
     if (item.hasPayload<KMime::Message::Ptr>()) {
-        //TODO add AllowDebugBaloo
-        KNote *note = new KNote(m_noteGUI, item, mDebugBaloo);
+        KNote *note = new KNote(m_noteGUI, item, mDebugAkonadiSearch);
         mNotes.insert(item.id(), note);
         connect(note, &KNote::sigShowNextNote,
                 this, &KNotesApp::slotWalkThroughNotes);
@@ -391,13 +389,14 @@ void KNotesApp::newNoteFromTextFile()
 {
     QString text;
     const QString filename = QFileDialog::getOpenFileName(this, i18n("Select Text File"), QString(),
-                                                          i18n("Text File (*.txt)"));
+                                                          QStringLiteral("%1 (*.txt)").arg(i18n("Text File")));
     if (!filename.isEmpty()) {
         QFile f(filename);
         if (f.open(QIODevice::ReadOnly | QIODevice::Text)) {
             text = QString::fromUtf8(f.readAll());
         } else {
-            KMessageBox::error(this, i18n("Error during open text file: %1", f.errorString()), i18n("Open Text File"));
+            KMessageBox::error(this, i18n("Error during open text file: %1", f.errorString()),
+                               i18n("Open Text File"));
             return;
         }
         newNote(i18n("Note from file '%1'", filename), text);
@@ -411,7 +410,9 @@ void KNotesApp::updateNetworkListener()
 
     if (NoteShared::NoteSharedGlobalConfig::receiveNotes()) {
         // create the socket and start listening for connections
-        m_publisher = new KDNSSD::PublicService(NoteShared::NoteSharedGlobalConfig::senderID(), QStringLiteral("_knotes._tcp"), NoteShared::NoteSharedGlobalConfig::port());
+        m_publisher = new KDNSSD::PublicService(NoteShared::NoteSharedGlobalConfig::senderID(),
+                                                QStringLiteral("_knotes._tcp"),
+                                                NoteShared::NoteSharedGlobalConfig::port());
         m_publisher->publishAsync();
     }
 }
