@@ -21,21 +21,18 @@
 #ifndef KNOTESAPP_H
 #define KNOTESAPP_H
 
-#include <QDomDocument>
-#include <QList>
-#include <QWidget>
-#include <QSessionManager>
-#include <kxmlguiclient.h>
-
 #include <AkonadiCore/Item>
-#include <QPointer>
 
+#include <KXMLGUIClient>
+
+#include <QDomDocument>
+#include <QPointer>
+#include <QSessionManager>
+#include <QWidget>
+
+class KNote;
 class KNoteFindDialog;
 class KNotesAkonadiTray;
-class QMenu;
-class KNote;
-class KXMLGUIBuilder;
-class KXMLGUIFactory;
 namespace NoteShared {
 class NotesChangeRecorder;
 class NotesAkonadiTreeModel;
@@ -44,8 +41,9 @@ class NotesAkonadiTreeModel;
 namespace KDNSSD {
 class PublicService;
 }
-class KJob;
-class QModelIndex;
+
+class QMenu;
+
 class KNotesApp : public QWidget, virtual public KXMLGUIClient
 {
     Q_OBJECT
@@ -99,18 +97,18 @@ private:
     void updateSystray();
     void createNote(const Akonadi::Item &item);
     void fetchNotesFromCollection(const Akonadi::Collection &col);
-    KXMLGUIFactory *m_guiFactory;
-    KXMLGUIBuilder *m_guiBuilder;
+    KXMLGUIFactory *m_guiFactory = nullptr;
+    KXMLGUIBuilder *m_guiBuilder = nullptr;
     QDomDocument m_noteGUI;
-    KNotesAkonadiTray *mTray;
-    QMenu *m_noteMenu;
+    KNotesAkonadiTray *mTray = nullptr;
+    QMenu *m_noteMenu = nullptr;
     QList<QAction *> m_noteActions;
-    KDNSSD::PublicService *m_publisher;
+    KDNSSD::PublicService *m_publisher = nullptr;
     QHash<Akonadi::Item::Id, KNote *> mNotes;
-    NoteShared::NotesChangeRecorder *mNoteRecorder;
-    NoteShared::NotesAkonadiTreeModel *mNoteTreeModel;
+    NoteShared::NotesChangeRecorder *mNoteRecorder = nullptr;
+    NoteShared::NotesAkonadiTreeModel *mNoteTreeModel = nullptr;
     QPointer<KNoteFindDialog> mFindDialog;
-    bool mDebugBaloo;
+    bool mDebugAkonadiSearch = false;
 };
 
 #endif
