@@ -18,18 +18,20 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
 
-#include "config-knotes.h"
+#include <config-knotes.h>
 #include "knotes_debug.h"
-#include "knotes-version.h"
-
 #include "knotes_options.h"
+#include "knotes-version.h"
 #include "apps/application.h"
 #include <KLocalizedString>
 #include <kdelibs4configmigrator.h>
 #include "notes/knotesmigrateapplication.h"
 
 #include <KAboutData>
+#include <KCrash>
+#include <KLocalizedString>
 
+#include <QApplication>
 #include <QCommandLineParser>
 #include <KCrash>
 
