@@ -18,39 +18,32 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
 
-#include "config-knotes.h"
+#include <config-knotes.h>
+
 #include "knoteconfigdialog.h"
-#include "notes/knote.h"
-#include "print/knoteprintselectthemecombobox.h"
+#include "notesharedglobalconfig.h"
+#include "knotecollectionconfigwidget.h"
 #include "knotedisplayconfigwidget.h"
 #include "knoteeditorconfigwidget.h"
-#include "knotecollectionconfigwidget.h"
 #include "knotesglobalconfig.h"
-#include "notesharedglobalconfig.h"
 #include "config/noteactionconfig.h"
+#include "config/notenetworkconfig.h"
+#include "print/knoteprintselectthemecombobox.h"
 
-#include "knotes-version.h"
-#include <QLineEdit>
-#include <qapplication.h>
-#include <kcolorbutton.h>
-#include <kconfig.h>
-#include <kfontrequester.h>
-#include <kiconloader.h>
+#include <KAuthorized>
+#include <KIconLoader>
 #include <KLocalizedString>
-#include <kwindowsystem.h>
-#include <QIcon>
 #include <KNS3/DownloadDialog>
-#include <QDialog>
+#include <KWindowSystem>
 
 #include <QCheckBox>
-#include <QGridLayout>
-#include <QHBoxLayout>
+#include <QApplication>
 #include <QLabel>
+#include <QLineEdit>
+#include <QPushButton>
+#include <QToolButton>
 #include <QVBoxLayout>
 #include <QWhatsThis>
-#include <QToolButton>
-
-#include <config/notenetworkconfig.h>
 
 KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
     : KCMultiDialog(parent)
@@ -74,8 +67,12 @@ KNoteConfigDialog::KNoteConfigDialog(const QString &title, QWidget *parent)
     addModule(QStringLiteral("knote_config_print"));
     addModule(QStringLiteral("knote_config_collection"));
     addModule(QStringLiteral("knote_config_misc"));
-    connect(button(QDialogButtonBox::Ok), &QPushButton::clicked, this, &KNoteConfigDialog::slotOk);
-    connect(button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &KNoteConfigDialog::slotDefaultClicked);
+
+    connect(button(QDialogButtonBox::Ok), &QPushButton::clicked,
+            this, &KNoteConfigDialog::slotOk);
+
+    connect(button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked,
+            this, &KNoteConfigDialog::slotDefaultClicked);
 }
 
 KNoteConfigDialog::~KNoteConfigDialog()
@@ -213,7 +210,7 @@ KNoteMiscConfig::KNoteMiscConfig(QWidget *parent)
     howItWorks->setContextMenuPolicy(Qt::NoContextMenu);
     lay->addStretch();
     load();
-    connect(mDefaultTitle, SIGNAL(textChanged(QString)), SLOT(changed()));
+    connect(mDefaultTitle, &QLineEdit::textChanged, this, QOverload<>::of(&KCModule::changed));
 }
 
 void KNoteMiscConfig::load()
@@ -266,22 +263,25 @@ KNotePrintConfig::KNotePrintConfig(QWidget *parent)
     layout->addWidget(label_PrintAction, 0, 0);
 
     mSelectTheme = new KNotePrintSelectThemeComboBox(this);
-    connect(mSelectTheme, SIGNAL(activated(int)), SLOT(slotThemeChanged()));
+    connect(mSelectTheme, QOverload<int>::of(&QComboBox::activated), this, &KNotePrintConfig::slotThemeChanged);
     label_PrintAction->setBuddy(mSelectTheme);
     layout->addWidget(mSelectTheme, 0, 1);
-
-    QToolButton *getNewTheme = new QToolButton;
-    getNewTheme->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
-    getNewTheme->setToolTip(i18n("Download new printing themes"));
-    connect(getNewTheme, &QToolButton::clicked, this, &KNotePrintConfig::slotDownloadNewThemes);
-    layout->addWidget(getNewTheme, 0, 2);
+    if (KAuthorized::authorize(QStringLiteral("ghns"))) {
+        QToolButton *getNewTheme = new QToolButton;
+        getNewTheme->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+        getNewTheme->setToolTip(i18n("Download new printing themes"));
+        connect(getNewTheme, &QToolButton::clicked, this, &KNotePrintConfig::slotDownloadNewThemes);
+        layout->addWidget(getNewTheme, 0, 2);
+    }
     lay->addStretch();
     load();
 }
 
 void KNotePrintConfig::slotDownloadNewThemes()
 {
-    QPointer<KNS3::DownloadDialog> downloadThemesDialog = new KNS3::DownloadDialog(QStringLiteral("knotes_printing_theme.knsrc"));
+    QPointer<KNS3::DownloadDialog> downloadThemesDialog
+        = new KNS3::DownloadDialog(QStringLiteral("knotes_printing_theme.knsrc"));
+
     if (downloadThemesDialog->exec()) {
         if (!downloadThemesDialog->changedEntries().isEmpty()) {
             mSelectTheme->loadThemes();
@@ -314,11 +314,10 @@ void KNotePrintConfig::defaults()
 KNoteCollectionConfig::KNoteCollectionConfig(QWidget *parent)
     : KCModule(parent)
 {
-    QHBoxLayout *lay = new QHBoxLayout;
+    QHBoxLayout *lay = new QHBoxLayout(this);
     mCollectionConfigWidget = new KNoteCollectionConfigWidget;
     lay->addWidget(mCollectionConfigWidget);
-    connect(mCollectionConfigWidget, SIGNAL(emitChanged(bool)), this, SLOT(changed()));
-    setLayout(lay);
+    connect(mCollectionConfigWidget, &KNoteCollectionConfigWidget::emitChanged, this, QOverload<>::of(&KCModule::changed));
     load();
 }
 
