@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -42,8 +42,8 @@ private Q_SLOTS:
 private:
     void readConfig();
     void writeConfig();
-    NoteShared::NoteListWidget *mNoteList;
-    QPushButton *mOkButton;
+    NoteShared::NoteListWidget *mNoteList = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 
 #endif // KNOTEDELETESELECTEDNOTESDIALOG_H
