@@ -45,11 +45,8 @@ using namespace KCalCore;
 #include <QIcon>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KSystemTimeZones>
-#include <QTemporaryFile>
+#include <QTimeZone>
 
-#include <QDBusConnection>
-#include <QDBusMessage>
 #include <QDropEvent>
 #include <QStandardPaths>
 
@@ -156,7 +153,7 @@ void KNotesPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(md)) {
-        KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(KSystemTimeZones::local()));
+        KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(md, cal)) {
             KCalCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
