@@ -22,7 +22,6 @@
 #include <KLocalizedString>
 #include <KStandardGuiItem>
 
-#include <QHBoxLayout>
 #include <QLabel>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
@@ -56,9 +55,8 @@ KNotesSelectDeleteNotesDialog::KNotesSelectDeleteNotesDialog(const QList<KNotesI
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Confirm Delete"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
