@@ -17,77 +17,65 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
-#include "config-knotes.h"
-#include "knotes_debug.h"
+
+#include <config-knotes.h>
+
 #include "knote.h"
+#include "knotes_debug.h"
+#include "knotedisplaysettings.h"
+#include "knoteedit.h"
+#include "knotesglobalconfig.h"
 #include "noteutils.h"
 #include "alarms/notealarmdialog.h"
+#include "attributes/notealarmattribute.h"
+#include "attributes/notedisplayattribute.h"
+#include "attributes/notelockattribute.h"
 #include "configdialog/knotesimpleconfigdialog.h"
-#include "print/knoteprintselectthemedialog.h"
 #include "notes/knotebutton.h"
-#include "utils/knoteutils.h"
-#include "configdialog/knoteconfigdialog.h"
-#include "knoteedit.h"
 #include "print/knoteprinter.h"
 #include "print/knoteprintobject.h"
-#include "knotesglobalconfig.h"
+#include "print/knoteprintselectthemedialog.h"
+#include "utils/knoteutils.h"
 
-#include "knotedisplaysettings.h"
-
-#include "attributes/notelockattribute.h"
-#include "attributes/notealarmattribute.h"
+#include <AkonadiCore/ItemModifyJob>
 
 #include <AkonadiSearch/Debug/akonadisearchdebugdialog.h>
 
 #include <KMime/KMimeMessage>
 
-#include <kactioncollection.h>
-#include <kcombobox.h>
-#include <kfiledialog.h>
-#include <kiconeffect.h>
-#include <kiconloader.h>
-#include <qinputdialog.h>
+#include <KActionCollection>
+#include <KComboBox>
+#include <KFileDialog>
+#include <KIconEffect>
+#include <KIconLoader>
 #include <KLocalizedString>
-#include <QMenu>
-#include <kmessagebox.h>
-#include <kselectaction.h>
-#include <kstandardaction.h>
+#include <KMessageBox>
+#include <KToggleAction>
+#include <KToolBar>
+#include <KWindowSystem>
+#include <KWindowSystem/NETWM>
+#include <KXMLGUIBuilder>
+#include <KXMLGUIFactory>
 
-#include <ktoggleaction.h>
-#include <ktoolbar.h>
-#include <kwindowsystem.h>
-#include <kxmlguibuilder.h>
-#include <kxmlguifactory.h>
-#include <netwm.h>
-
-#include <AkonadiCore/ItemModifyJob>
-
-#include <QBoxLayout>
-#include <QCheckBox>
-#include <QFile>
-#include <QHBoxLayout>
-#include <QLabel>
-#include <QPixmap>
-#include <QSize>
-#include <QSizeGrip>
-#include <QTextStream>
-#include <QVBoxLayout>
-#include <QPointer>
-#include <QFocusEvent>
-#include <QMimeData>
-#include <QDesktopWidget>
 #include <QApplication>
+#include <QCheckBox>
+#include <QDesktopWidget>
+#include <QInputDialog>
+#include <QLabel>
+#include <QMenu>
+#include <QMimeData>
+#include <QPointer>
+#include <QSizeGrip>
+#include <QVBoxLayout>
 
 #if KDEPIM_HAVE_X11
 #include <fixx11h.h>
 #include <QX11Info>
-
-#include <attributes/notedisplayattribute.h>
 #endif
 
 //#define DEBUG_SAVE_NOTE 1
 
-KNote::KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowDebugBaloo, QWidget *parent)
+KNote::KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowAkonadiSearchDebug, QWidget *parent)
     : QFrame(parent, Qt::FramelessWindowHint)
     , mItem(item)
     , m_label(nullptr)
@@ -97,7 +85,7 @@ KNote::KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allow
     , m_editor(nullptr)
     , m_kwinConf(KSharedConfig::openConfig(QStringLiteral("kwinrc")))
     , mDisplayAttribute(new KNoteDisplaySettings)
-    , mAllowDebugBaloo(allowDebugBaloo)
+    , mAllowDebugAkonadiSearch(allowAkonadiSearchDebug)
 {
     if (mItem.hasAttribute<NoteShared::NoteDisplayAttribute>()) {
         mDisplayAttribute->setDisplayAttribute(mItem.attribute<NoteShared::NoteDisplayAttribute>());
@@ -157,13 +145,13 @@ void KNote::setChangeItem(const Akonadi::Item &item, const QSet<QByteArray> &set
 void KNote::slotKill(bool force)
 {
     if (!force
-        && (KMessageBox::warningContinueCancel(this,
-                                               i18n("<qt>Do you really want to delete note <b>%1</b>?</qt>",
-                                                    m_label->text()),
-                                               i18n("Confirm Delete"),
-                                               KGuiItem(i18n("&Delete"), QStringLiteral("edit-delete")),
-                                               KStandardGuiItem::cancel(),
-                                               QStringLiteral("ConfirmDeleteNote")) != KMessageBox::Continue)) {
+        && KMessageBox::warningContinueCancel(this,
+                                              i18n("<qt>Do you really want to delete note <b>%1</b>?</qt>", m_label->text()),
+                                              i18n("Confirm Delete"),
+                                              KGuiItem(i18n("&Delete"),
+                                                       QStringLiteral("edit-delete")),
+                                              KStandardGuiItem::cancel(),
+                                              QStringLiteral("ConfirmDeleteNote")) != KMessageBox::Continue) {
         return;
     }
 
@@ -178,7 +166,8 @@ void KNote::saveNote(bool force, bool sync)
         return;
     }
     bool needToSave = false;
-    NoteShared::NoteDisplayAttribute *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    NoteShared::NoteDisplayAttribute *attribute
+        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     const QPoint notePosition = pos();
     if (attribute->position() != notePosition) {
         needToSave = true;
@@ -285,7 +274,8 @@ void KNote::slotRename()
     bool ok;
     const QString oldName = m_label->text();
     const QString newName = QInputDialog::getText(this, QString(),
-                                                  i18n("Please enter the new name:"), QLineEdit::Normal, m_label->text(), &ok);
+                                                  i18n("Please enter the new name:"),
+                                                  QLineEdit::Normal, m_label->text(), &ok);
     if (!ok || (oldName == newName)) {   // handle cancel
         return;
     }
@@ -351,7 +341,8 @@ void KNote::slotUpdateReadOnly()
 void KNote::updateAllAttributes()
 {
 #if KDEPIM_HAVE_X11
-    NoteShared::NoteDisplayAttribute *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    NoteShared::NoteDisplayAttribute *attribute
+        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     KWindowInfo info(winId(), NET::WMDesktop);
     const int count = KWindowSystem::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
@@ -391,7 +382,8 @@ void KNote::slotSetAlarm()
         bool needToModify = true;
         QDateTime dateTime = dlg->alarm();
         if (dateTime.isValid()) {
-            NoteShared::NoteAlarmAttribute *attribute = mItem.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
+            NoteShared::NoteAlarmAttribute *attribute
+                = mItem.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
             attribute->setDateTime(dateTime);
         } else {
             if (mItem.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
@@ -437,7 +429,8 @@ void KNote::slotPreferences()
 {
     // create a new preferences dialog...
     QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog(name(), this);
-    NoteShared::NoteDisplayAttribute *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    NoteShared::NoteDisplayAttribute *attribute
+        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     attribute->setSize(QSize(width(), height()));
 
     dialog->load(mItem, m_editor->acceptRichText());
@@ -547,7 +540,8 @@ void KNote::slotSaveAs()
         QTextStream stream(&file);
         if (htmlFormatAndSaveAsHtml) {
             QString htmlStr = m_editor->toHtml();
-            htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""), QStringLiteral("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
+            htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""),
+                            QStringLiteral("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
             stream <<  htmlStr;
         } else {
             stream << m_editor->toPlainText();
@@ -600,7 +594,8 @@ void KNote::updateKeepAboveBelow(bool save)
 #else
     NET::States state = 0; // neutral state, TODO
 #endif
-    NoteShared::NoteDisplayAttribute *attribute = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+    NoteShared::NoteDisplayAttribute *attribute
+        = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
     if (m_keepAbove->isChecked()) {
         attribute->setKeepAbove(true);
         attribute->setKeepBelow(false);
@@ -653,7 +648,8 @@ void KNote::slotUpdateDesktopActions()
     m_toDesktop->addAction(separator);
     const int count = KWindowSystem::numberOfDesktops();
     for (int n = 1; n <= count; ++n) {
-        QAction *desktopAct = m_toDesktop->addAction(QStringLiteral("&%1 %2").arg(n).arg(KWindowSystem::desktopName(n)));
+        QAction *desktopAct
+            = m_toDesktop->addAction(QStringLiteral("&%1 %2").arg(n).arg(KWindowSystem::desktopName(n)));
         desktopAct->setData(n);
         if (info.isOnDesktop(n)) {
             desktopAct->setChecked(true);
@@ -682,9 +678,7 @@ void KNote::createActions()
 {
     // create the menu items for the note - not the editor...
     // rename, mail, print, save as, insert date, alarm, close, delete, new note
-    QAction *action;
-
-    action = new QAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New"), this);
+    QAction *action = new QAction(QIcon::fromTheme(QStringLiteral("document-new")), i18n("New"), this);
     actionCollection()->addAction(QStringLiteral("new_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotRequestNewNote);
 
@@ -724,9 +718,12 @@ void KNote::createActions()
                          this);
     actionCollection()->addAction(QStringLiteral("save_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotSaveAs);
-    actionCollection()->addAction(KStandardAction::Print, QStringLiteral("print_note"), this, SLOT(slotPrint()));
+    action = actionCollection()->addAction(KStandardAction::Print, QStringLiteral("print_note"));
+    connect(action, &QAction::triggered, this, &KNote::slotPrint);
+
+    action = actionCollection()->addAction(KStandardAction::PrintPreview, QStringLiteral("print_preview_note"));
+    connect(action, &QAction::triggered, this, &KNote::slotPrintPreview);
 
-    actionCollection()->addAction(KStandardAction::PrintPreview, QStringLiteral("print_preview_note"), this, SLOT(slotPrintPreview()));
     action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Preferences..."), this);
     actionCollection()->addAction(QStringLiteral("configure_note"), action);
     connect(action, &QAction::triggered, this, &KNote::slotPreferences);
@@ -744,8 +741,10 @@ void KNote::createActions()
 #if KDEPIM_HAVE_X11
     m_toDesktop = new KSelectAction(i18n("To Desktop"), this);
     actionCollection()->addAction(QStringLiteral("to_desktop"), m_toDesktop);
-    connect(m_toDesktop, static_cast<void (KSelectAction::*)(QAction *)>(&KSelectAction::triggered), this, &KNote::slotPopupActionToDesktop);
-    connect(m_toDesktop->menu(), &QMenu::aboutToShow, this, &KNote::slotUpdateDesktopActions);
+    connect(m_toDesktop, QOverload<QAction *>::of(&KSelectAction::triggered),
+            this, &KNote::slotPopupActionToDesktop);
+    connect(m_toDesktop->menu(), &QMenu::aboutToShow,
+            this, &KNote::slotUpdateDesktopActions);
     // initially populate it, otherwise stays disabled
     slotUpdateDesktopActions();
 #endif
@@ -759,11 +758,11 @@ void KNote::createActions()
     foreach (QAction *action, actionCollection()->actions()) {
         action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     }
-    if (mAllowDebugBaloo) {
+    if (mAllowDebugAkonadiSearch) {
         //Don't translate it it's just for debugging
-        action = new QAction(QStringLiteral("Debug Baloo..."), this);
-        actionCollection()->addAction(QStringLiteral("debug_baloo"), action);
-        connect(action, &QAction::triggered, this, &KNote::slotDebugBaloo);
+        action = new QAction(QStringLiteral("Debug Akonadi Search..."), this);
+        actionCollection()->addAction(QStringLiteral("debug_akonadi_search"), action);
+        connect(action, &QAction::triggered, this, &KNote::slotDebugAkonadiSearch);
     }
 }
 
@@ -980,7 +979,7 @@ void KNote::setColor(const QColor &fg, const QColor &bg)
     // better: from light(150) to light(100) to light(75)
     // QLinearGradient g( width()/2, 0, width()/2, height() );
     // g.setColorAt( 0, bg );
-    // g.setColorAt( 1, bg.dark(150) );
+    // g.setColorAt( 1, bg.darker(150) );
 
     p.setColor(QPalette::Window, bg);
     // p.setBrush( QPalette::Window,     g );
@@ -990,7 +989,7 @@ void KNote::setColor(const QColor &fg, const QColor &bg)
     p.setColor(QPalette::WindowText, fg);
     p.setColor(QPalette::Text, fg);
 
-    p.setColor(QPalette::Button, bg.dark(116));
+    p.setColor(QPalette::Button, bg.darker(116));
     p.setColor(QPalette::ButtonText, fg);
 
     //p.setColor( QPalette::Highlight,  bg );
@@ -999,16 +998,16 @@ void KNote::setColor(const QColor &fg, const QColor &bg)
     // order: Light, Midlight, Button, Mid, Dark, Shadow
 
     // the shadow
-    p.setColor(QPalette::Light, bg.light(180));
-    p.setColor(QPalette::Midlight, bg.light(150));
-    p.setColor(QPalette::Mid, bg.light(150));
-    p.setColor(QPalette::Dark, bg.dark(108));
-    p.setColor(QPalette::Shadow, bg.dark(116));
+    p.setColor(QPalette::Light, bg.lighter(180));
+    p.setColor(QPalette::Midlight, bg.lighter(150));
+    p.setColor(QPalette::Mid, bg.lighter(150));
+    p.setColor(QPalette::Dark, bg.darker(108));
+    p.setColor(QPalette::Shadow, bg.darker(116));
 
     setPalette(p);
 
     // darker values for the active label
-    p.setColor(QPalette::Active, QPalette::Base, bg.dark(116));
+    p.setColor(QPalette::Active, QPalette::Base, bg.darker(116));
 
     m_label->setPalette(p);
 
@@ -1091,7 +1090,8 @@ void KNote::showEvent(QShowEvent *)
         slotUpdateShowInTaskbar();
         toDesktop(mDisplayAttribute->desktop());
         move(mDisplayAttribute->position());
-        NoteShared::NoteDisplayAttribute *attr = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+        NoteShared::NoteDisplayAttribute *attr
+            = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
         saveNoteContent();
         attr->setIsHidden(false);
         if (!mBlockSave) {
@@ -1136,7 +1136,8 @@ void KNote::dropEvent(QDropEvent *e)
     if (md->hasColor()) {
         const QColor bg = qvariant_cast<QColor>(md->colorData());
 
-        NoteShared::NoteDisplayAttribute *attr = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
+        NoteShared::NoteDisplayAttribute *attr
+            = mItem.attribute<NoteShared::NoteDisplayAttribute>(Akonadi::Item::AddIfMissing);
         saveNoteContent();
         attr->setBackgroundColor(bg);
         Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(mItem);
@@ -1195,8 +1196,7 @@ bool KNote::eventFilter(QObject *o, QEvent *ev)
     if (o == m_editor) {
         if (ev->type() == QEvent::FocusOut) {
             QFocusEvent *fe = static_cast<QFocusEvent *>(ev);
-            if (fe->reason() != Qt::PopupFocusReason
-                && fe->reason() != Qt::MouseFocusReason) {
+            if (fe->reason() != Qt::PopupFocusReason && fe->reason() != Qt::MouseFocusReason) {
                 updateFocus();
                 if (!mBlockSave) {
                     saveNote(true);
@@ -1217,7 +1217,7 @@ Akonadi::Item KNote::item() const
     return mItem;
 }
 
-void KNote::slotDebugBaloo()
+void KNote::slotDebugAkonadiSearch()
 {
     QPointer<Akonadi::Search::AkonadiSearchDebugDialog> dlg = new Akonadi::Search::AkonadiSearchDebugDialog;
     dlg->setAkonadiId(mItem.id());
