@@ -20,36 +20,36 @@
 
 #ifndef KNOTE_H
 #define KNOTE_H
-#include "config-knotes.h"
+
+#include <config-knotes.h>
+#include "knoteinterface.h"
+
+#include <AkonadiCore/Item>
+
+#include <KSharedConfig>
+#include <KXMLGUIClient>
+
 #include <QDomDocument>
 #include <QEvent>
 #include <QFrame>
 
-#include <kconfig.h>
-#include <kxmlguiclient.h>
-#include <KSharedConfig>
-#include <AkonadiCore/Item>
-#include "knoteinterface.h"
-
-class KNoteDisplaySettings;
-
-class QLabel;
-class QLayout;
-class QSizeGrip;
-
-class QMenu;
 class KNoteButton;
+class KNoteDisplaySettings;
 class KNoteEdit;
+
 class KSelectAction;
 class KToggleAction;
 class KToolBar;
-class KJob;
+
+class QLabel;
+class QMenu;
+class QSizeGrip;
 
 class KNote : public QFrame, virtual public KXMLGUIClient, public KNoteInterface
 {
     Q_OBJECT
 public:
-    explicit KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowDebugBaloo = false, QWidget *parent = nullptr);
+    explicit KNote(const QDomDocument &buildDoc, const Akonadi::Item &item, bool allowAkonadiSearchDebug = false, QWidget *parent = nullptr);
     ~KNote();
 
     void setChangeItem(const Akonadi::Item &item, const QSet<QByteArray> &set = QSet<QByteArray>());
@@ -116,7 +116,7 @@ private Q_SLOTS:
 
     void slotRequestNewNote();
     void slotNoteSaved(KJob *job);
-    void slotDebugBaloo();
+    void slotDebugAkonadiSearch();
 
 private:
     void updateKeepAboveBelow(bool save = true);
@@ -140,27 +140,27 @@ private:
     void updateAllAttributes();
     void saveNoteContent();
     Akonadi::Item mItem;
-    QLayout *m_noteLayout;
-    QLabel *m_label;
-    QSizeGrip *m_grip;
-    KNoteButton *m_button;
-    KToolBar *m_tool;
-    KNoteEdit *m_editor;
+    QLayout *m_noteLayout = nullptr;
+    QLabel *m_label = nullptr;
+    QSizeGrip *m_grip = nullptr;
+    KNoteButton *m_button = nullptr;
+    KToolBar *m_tool = nullptr;
+    KNoteEdit *m_editor = nullptr;
 
-    QMenu *m_menu;
+    QMenu *m_menu = nullptr;
 
-    KToggleAction *m_readOnly;
+    KToggleAction *m_readOnly = nullptr;
 
 #if KDEPIM_HAVE_X11
-    KSelectAction *m_toDesktop;
+    KSelectAction *m_toDesktop = nullptr;
 #endif
-    KToggleAction *m_keepAbove;
-    KToggleAction *m_keepBelow;
+    KToggleAction *m_keepAbove = nullptr;
+    KToggleAction *m_keepBelow = nullptr;
 
     KSharedConfig::Ptr m_kwinConf;
 
-    KNoteDisplaySettings *mDisplayAttribute;
-    bool mAllowDebugBaloo;
+    KNoteDisplaySettings *mDisplayAttribute = nullptr;
+    bool mAllowDebugAkonadiSearch;
 };
 
 #endif
