@@ -17,10 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 #include "knotedisplaysettings.h"
-#include "attributes/notelockattribute.h"
 #include "knotesglobalconfig.h"
-
-#include <attributes/notedisplayattribute.h>
+#include "attributes/notedisplayattribute.h"
 
 KNoteDisplaySettings::KNoteDisplaySettings(NoteShared::NoteDisplayAttribute *attr)
     : mDisplayAttribute(attr)
