@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -19,9 +19,10 @@
 #ifndef KNOTESMIGRATEAPPLICATION_H
 #define KNOTESMIGRATEAPPLICATION_H
 
-#include <pimcommon/migrateapplicationfiles.h>
 #include "knotes_export.h"
 
+#include <PimCommon/MigrateApplicationFiles>
+
 class KNOTES_EXPORT KNotesMigrateApplication
 {
 public:
