@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Montel Laurent <montel@kde.org>
+   Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -20,19 +20,18 @@
 #ifndef KNOTEGRANTLEEPRINT_H
 #define KNOTEGRANTLEEPRINT_H
 
-#include <QObject>
-#include <genericgrantleeformatter.h>
 #include "knotes_export.h"
-namespace Grantlee {
-class Engine;
-}
+
+#include <PimCommon/GenericGrantleeFormatter>
+
 class KNotePrintObject;
+
 class KNOTES_EXPORT KNoteGrantleePrint : public PimCommon::GenericGrantleeFormatter
 {
     Q_OBJECT
 public:
     explicit KNoteGrantleePrint(QObject *parent = nullptr);
-    KNoteGrantleePrint(const QString &themePath, QObject *parent = nullptr);
+    explicit KNoteGrantleePrint(const QString &themePath, QObject *parent = nullptr);
     ~KNoteGrantleePrint();
 
     QString notesToHtml(const QList<KNotePrintObject *> &lst);
