@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -47,7 +47,7 @@ private:
 
     QFont m_defaultFont;
     QString mHtmlPreviewText;
-    KNoteGrantleePrint *mGrantleePrint;
+    KNoteGrantleePrint *mGrantleePrint = nullptr;
 };
 
 #endif // KNOTEPRINTER
