@@ -19,15 +19,13 @@
 
 #include "knoteprintobject.h"
 #include "attributes/notealarmattribute.h"
-#include "attributes/notelockattribute.h"
+#include "attributes/notedisplayattribute.h"
 #include "attributes/notelockattribute.h"
 
 #include <KMime/KMimeMessage>
 
 #include <QLocale>
 
-#include <attributes/notedisplayattribute.h>
-
 KNotePrintObject::KNotePrintObject(const Akonadi::Item &item, QObject *parent)
     : QObject(parent)
     , mItem(item)
