@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -34,7 +34,7 @@ public:
     QString selectedTheme() const;
 
 private:
-    KNotePrintSelectThemeComboBox *mThemes;
+    KNotePrintSelectThemeComboBox *mThemes = nullptr;
 };
 
 #endif // KNOTEPRINTSELECTTHEMEDIALOG_H
